/*     */ package org.apache.batik.util;
/*     */ 
/*     */ import java.io.DataInputStream;
/*     */ import java.io.File;
/*     */ import java.io.FileInputStream;
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collections;
/*     */ import java.util.Enumeration;
/*     */ import java.util.HashMap;
/*     */ import java.util.HashSet;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import java.util.Set;
/*     */ import java.util.jar.JarFile;
/*     */ import java.util.zip.ZipEntry;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class ClassFileUtilities
/*     */ {
/*     */   public static final byte CONSTANT_UTF8_INFO = 1;
/*     */   public static final byte CONSTANT_INTEGER_INFO = 3;
/*     */   public static final byte CONSTANT_FLOAT_INFO = 4;
/*     */   public static final byte CONSTANT_LONG_INFO = 5;
/*     */   public static final byte CONSTANT_DOUBLE_INFO = 6;
/*     */   public static final byte CONSTANT_CLASS_INFO = 7;
/*     */   public static final byte CONSTANT_STRING_INFO = 8;
/*     */   public static final byte CONSTANT_FIELDREF_INFO = 9;
/*     */   public static final byte CONSTANT_METHODREF_INFO = 10;
/*     */   public static final byte CONSTANT_INTERFACEMETHODREF_INFO = 11;
/*     */   public static final byte CONSTANT_NAMEANDTYPE_INFO = 12;
/*     */   
/*     */   public static void main(String[] args) {
/*  80 */     boolean showFiles = false;
/*  81 */     if (args.length == 1 && args[0].equals("-f")) {
/*  82 */       showFiles = true;
/*  83 */     } else if (args.length != 0) {
/*  84 */       System.err.println("usage: org.apache.batik.util.ClassFileUtilities [-f]");
/*  85 */       System.err.println();
/*  86 */       System.err.println("  -f    list files that cause each jar file dependency");
/*  87 */       System.exit(1);
/*     */     } 
/*     */     
/*  90 */     File cwd = new File(".");
/*  91 */     File buildDir = null;
/*  92 */     String[] cwdFiles = cwd.list();
/*  93 */     for (int i = 0; i < cwdFiles.length; i++) {
/*  94 */       if (cwdFiles[i].startsWith("batik-")) {
/*  95 */         buildDir = new File(cwdFiles[i]);
/*  96 */         if (!buildDir.isDirectory()) {
/*  97 */           buildDir = null;
/*     */         } else {
/*     */           break;
/*     */         } 
/*     */       } 
/*     */     } 
/* 103 */     if (buildDir == null || !buildDir.isDirectory()) {
/* 104 */       System.out.println("Directory 'batik-xxx' not found in current directory!");
/*     */       
/*     */       return;
/*     */     } 
/*     */     try {
/* 109 */       Map cs = new HashMap();
/* 110 */       Map js = new HashMap();
/* 111 */       collectJars(buildDir, js, cs);
/*     */       
/* 113 */       Set classpath = new HashSet();
/* 114 */       Iterator i = js.values().iterator();
/* 115 */       while (i.hasNext()) {
/* 116 */         classpath.add(((Jar)i.next()).jarFile);
/*     */       }
/*     */       
/* 119 */       i = cs.values().iterator();
/* 120 */       while (i.hasNext()) {
/* 121 */         ClassFile fromFile = (ClassFile)i.next();
/*     */         
/* 123 */         Set result = getClassDependencies(fromFile.getInputStream(), classpath, false);
/*     */         
/* 125 */         Iterator j = result.iterator();
/* 126 */         while (j.hasNext()) {
/* 127 */           ClassFile toFile = (ClassFile)cs.get(j.next());
/* 128 */           if (fromFile != toFile && toFile != null) {
/* 129 */             fromFile.deps.add(toFile);
/*     */           }
/*     */         } 
/*     */       } 
/*     */       
/* 134 */       i = cs.values().iterator();
/* 135 */       while (i.hasNext()) {
/* 136 */         ClassFile fromFile = (ClassFile)i.next();
/* 137 */         Iterator j = fromFile.deps.iterator();
/* 138 */         while (j.hasNext()) {
/* 139 */           ClassFile toFile = (ClassFile)j.next();
/* 140 */           Jar fromJar = fromFile.jar;
/* 141 */           Jar toJar = toFile.jar;
/* 142 */           if (fromFile.name.equals(toFile.name) || toJar == fromJar || fromJar.files.contains(toFile.name)) {
/*     */             continue;
/*     */           }
/*     */ 
/*     */           
/* 147 */           Integer n = (Integer)fromJar.deps.get(toJar);
/* 148 */           if (n == null) {
/* 149 */             fromJar.deps.put(toJar, new Integer(1)); continue;
/*     */           } 
/* 151 */           fromJar.deps.put(toJar, new Integer(n.intValue() + 1));
/*     */         } 
/*     */       } 
/*     */ 
/*     */       
/* 156 */       List triples = new ArrayList(10);
/* 157 */       i = js.values().iterator();
/* 158 */       while (i.hasNext()) {
/* 159 */         Jar fromJar = (Jar)i.next();
/* 160 */         Iterator j = fromJar.deps.keySet().iterator();
/* 161 */         while (j.hasNext()) {
/* 162 */           Jar toJar = (Jar)j.next();
/* 163 */           Triple t = new Triple();
/* 164 */           t.from = fromJar;
/* 165 */           t.to = toJar;
/* 166 */           t.count = ((Integer)fromJar.deps.get(toJar)).intValue();
/* 167 */           triples.add(t);
/*     */         } 
/*     */       } 
/* 170 */       Collections.sort(triples);
/*     */       
/* 172 */       i = triples.iterator();
/* 173 */       while (i.hasNext()) {
/* 174 */         Triple t = (Triple)i.next();
/* 175 */         System.out.println(t.count + "," + t.from.name + "," + t.to.name);
/*     */         
/* 177 */         if (showFiles) {
/* 178 */           Iterator j = t.from.files.iterator();
/* 179 */           while (j.hasNext()) {
/* 180 */             ClassFile fromFile = (ClassFile)j.next();
/* 181 */             Iterator k = fromFile.deps.iterator();
/* 182 */             while (k.hasNext()) {
/* 183 */               ClassFile toFile = (ClassFile)k.next();
/* 184 */               if (toFile.jar == t.to && !t.from.files.contains(toFile.name))
/*     */               {
/* 186 */                 System.out.println("\t" + fromFile.name + " --> " + toFile.name);
/*     */               }
/*     */             }
/*     */           
/*     */           } 
/*     */         } 
/*     */       } 
/*     */     } catch (IOException e) {
/*     */       
/* 195 */       e.printStackTrace();
/*     */     } 
/*     */   }
/*     */   
/*     */   protected static class ClassFile {
/*     */     public String name;
/* 201 */     public List deps = new ArrayList(10);
/*     */     public ClassFileUtilities.Jar jar;
/*     */     
/* 204 */     public InputStream getInputStream() throws IOException { return this.jar.jarFile.getInputStream(this.jar.jarFile.getEntry(this.name)); }
/*     */   }
/*     */   
/*     */   protected static class Jar
/*     */   {
/*     */     public String name;
/*     */     public File file;
/*     */     public JarFile jarFile;
/* 212 */     public Map deps = new HashMap();
/* 213 */     public Set files = new HashSet();
/*     */   }
/*     */   
/*     */   protected static class Triple implements Comparable {
/*     */     public ClassFileUtilities.Jar from;
/*     */     public ClassFileUtilities.Jar to;
/*     */     public int count;
/*     */     
/* 221 */     public int compareTo(Object o) { return ((Triple)o).count - this.count; }
/*     */   }
/*     */ 
/*     */   
/*     */   private static void collectJars(File dir, Map jars, Map classFiles) throws IOException {
/* 226 */     File[] files = dir.listFiles();
/* 227 */     for (int i = 0; i < files.length; i++) {
/* 228 */       String n = files[i].getName();
/* 229 */       if (n.endsWith(".jar") && files[i].isFile()) {
/* 230 */         Jar j = new Jar();
/* 231 */         j.name = files[i].getPath();
/* 232 */         j.file = files[i];
/* 233 */         j.jarFile = new JarFile(files[i]);
/* 234 */         jars.put(j.name, j);
/*     */         
/* 236 */         Enumeration entries = j.jarFile.entries();
/* 237 */         while (entries.hasMoreElements()) {
/* 238 */           ZipEntry ze = (ZipEntry)entries.nextElement();
/* 239 */           String name = ze.getName();
/* 240 */           if (name.endsWith(".class")) {
/* 241 */             ClassFile cf = new ClassFile();
/* 242 */             cf.name = name;
/* 243 */             cf.jar = j;
/* 244 */             classFiles.put(j.name + '!' + cf.name, cf);
/* 245 */             j.files.add(cf);
/*     */           } 
/*     */         } 
/* 248 */       } else if (files[i].isDirectory()) {
/* 249 */         collectJars(files[i], jars, classFiles);
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 266 */   public static Set getClassDependencies(String path, Set classpath, boolean rec) throws IOException { return getClassDependencies(new FileInputStream(path), classpath, rec); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Set getClassDependencies(InputStream is, Set classpath, boolean rec) throws IOException {
/* 274 */     Set result = new HashSet();
/* 275 */     Set done = new HashSet();
/*     */     
/* 277 */     computeClassDependencies(is, classpath, done, result, rec);
/*     */     
/* 279 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void computeClassDependencies(InputStream is, Set classpath, Set done, Set result, boolean rec) throws IOException {
/* 289 */     Iterator it = getClassDependencies(is).iterator();
/* 290 */     while (it.hasNext()) {
/* 291 */       String s = (String)it.next();
/* 292 */       if (!done.contains(s)) {
/* 293 */         done.add(s);
/*     */         
/* 295 */         Iterator cpit = classpath.iterator();
/* 296 */         while (cpit.hasNext()) {
/* 297 */           InputStream depis = null;
/* 298 */           String path = null;
/* 299 */           Object cpEntry = cpit.next();
/* 300 */           if (cpEntry instanceof JarFile) {
/* 301 */             JarFile jarFile = (JarFile)cpEntry;
/* 302 */             String classFileName = s + ".class";
/* 303 */             ZipEntry ze = jarFile.getEntry(classFileName);
/* 304 */             if (ze != null) {
/* 305 */               path = jarFile.getName() + '!' + classFileName;
/* 306 */               depis = jarFile.getInputStream(ze);
/*     */             } 
/*     */           } else {
/* 309 */             path = (String)cpEntry + '/' + s + ".class";
/* 310 */             File f = new File(path);
/* 311 */             if (f.isFile()) {
/* 312 */               depis = new FileInputStream(f);
/*     */             }
/*     */           } 
/*     */           
/* 316 */           if (depis != null) {
/* 317 */             result.add(path);
/*     */             
/* 319 */             if (rec) {
/* 320 */               computeClassDependencies(depis, classpath, done, result, rec);
/*     */             }
/*     */           } 
/*     */         } 
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Set getClassDependencies(InputStream is) throws IOException {
/* 334 */     DataInputStream dis = new DataInputStream(is);
/*     */     
/* 336 */     if (dis.readInt() != -889275714) {
/* 337 */       throw new IOException("Invalid classfile");
/*     */     }
/*     */     
/* 340 */     dis.readInt();
/*     */     
/* 342 */     int len = dis.readShort();
/* 343 */     String[] strs = new String[len];
/* 344 */     Set classes = new HashSet();
/* 345 */     Set desc = new HashSet();
/*     */     
/* 347 */     for (int i = 1; i < len; i++) {
/* 348 */       int constCode = dis.readByte() & 0xFF;
/* 349 */       switch (constCode) {
/*     */         case 5:
/*     */         case 6:
/* 352 */           dis.readLong();
/* 353 */           i++;
/*     */           break;
/*     */         
/*     */         case 3:
/*     */         case 4:
/*     */         case 9:
/*     */         case 10:
/*     */         case 11:
/* 361 */           dis.readInt();
/*     */           break;
/*     */         
/*     */         case 7:
/* 365 */           classes.add(new Integer(dis.readShort() & 0xFFFF));
/*     */           break;
/*     */         
/*     */         case 8:
/* 369 */           dis.readShort();
/*     */           break;
/*     */         
/*     */         case 12:
/* 373 */           dis.readShort();
/* 374 */           desc.add(new Integer(dis.readShort() & 0xFFFF));
/*     */           break;
/*     */         
/*     */         case 1:
/* 378 */           strs[i] = dis.readUTF();
/*     */           break;
/*     */         
/*     */         default:
/* 382 */           throw new RuntimeException("unexpected data in constant-pool:" + constCode);
/*     */       } 
/*     */     
/*     */     } 
/* 386 */     Set result = new HashSet();
/*     */     
/* 388 */     Iterator it = classes.iterator();
/* 389 */     while (it.hasNext()) {
/* 390 */       result.add(strs[((Integer)it.next()).intValue()]);
/*     */     }
/*     */     
/* 393 */     it = desc.iterator();
/* 394 */     while (it.hasNext()) {
/* 395 */       result.addAll(getDescriptorClasses(strs[((Integer)it.next()).intValue()]));
/*     */     }
/*     */     
/* 398 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected static Set getDescriptorClasses(String desc) {
/*     */     StringBuffer sb, sb;
/* 405 */     Set result = new HashSet();
/* 406 */     int i = 0;
/* 407 */     char c = desc.charAt(i);
/* 408 */     switch (c) {
/*     */       case '(':
/*     */         while (true) {
/* 411 */           StringBuffer sb; c = desc.charAt(++i);
/* 412 */           switch (c) {
/*     */             case '[':
/*     */               do {
/* 415 */                 c = desc.charAt(++i);
/* 416 */               } while (c == '[');
/* 417 */               if (c != 'L') {
/*     */                 continue;
/*     */               }
/*     */             
/*     */             case 'L':
/* 422 */               c = desc.charAt(++i);
/* 423 */               sb = new StringBuffer();
/* 424 */               while (c != ';') {
/* 425 */                 sb.append(c);
/* 426 */                 c = desc.charAt(++i);
/*     */               } 
/* 428 */               result.add(sb.toString());
/*     */               continue;
/*     */             
/*     */             default:
/*     */               continue;
/*     */             case ')':
/*     */               break;
/*     */           } 
/*     */           break;
/*     */         } 
/* 438 */         c = desc.charAt(++i);
/* 439 */         switch (c) {
/*     */           case '[':
/*     */             do {
/* 442 */               c = desc.charAt(++i);
/* 443 */             } while (c == '[');
/* 444 */             if (c != 'L') {
/*     */               break;
/*     */             }
/*     */           
/*     */           case 'L':
/* 449 */             c = desc.charAt(++i);
/* 450 */             sb = new StringBuffer();
/* 451 */             while (c != ';') {
/* 452 */               sb.append(c);
/* 453 */               c = desc.charAt(++i);
/*     */             } 
/* 455 */             result.add(sb.toString());
/*     */             break;
/*     */         } 
/*     */ 
/*     */         
/*     */         break;
/*     */ 
/*     */       
/*     */       case '[':
/*     */         do {
/* 465 */           c = desc.charAt(++i);
/* 466 */         } while (c == '[');
/* 467 */         if (c != 'L') {
/*     */           break;
/*     */         }
/*     */       
/*     */       case 'L':
/* 472 */         c = desc.charAt(++i);
/* 473 */         sb = new StringBuffer();
/* 474 */         while (c != ';') {
/* 475 */           sb.append(c);
/* 476 */           c = desc.charAt(++i);
/*     */         } 
/* 478 */         result.add(sb.toString());
/*     */         break;
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 484 */     return result;
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-util.jar!\org\apache\bati\\util\ClassFileUtilities.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */