/*     */ package org.apache.batik.util;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.net.URL;
/*     */ import java.util.ArrayList;
/*     */ import java.util.HashMap;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import org.apache.batik.Version;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class ParsedURL
/*     */ {
/*     */   ParsedURLData data;
/*     */   String userAgent;
/*  79 */   private static Map handlersMap = null;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  86 */   private static ParsedURLProtocolHandler defaultHandler = new ParsedURLDefaultProtocolHandler();
/*     */ 
/*     */   
/*  89 */   private static String globalUserAgent = "Batik/" + Version.getVersion();
/*     */   
/*  91 */   public static String getGlobalUserAgent() { return globalUserAgent; }
/*     */ 
/*     */   
/*  94 */   public static void setGlobalUserAgent(String userAgent) { globalUserAgent = userAgent; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static Map getHandlersMap() {
/* 104 */     if (handlersMap != null) return handlersMap;
/*     */     
/* 106 */     handlersMap = new HashMap();
/* 107 */     registerHandler(new ParsedURLDataProtocolHandler());
/* 108 */     registerHandler(new ParsedURLJarProtocolHandler());
/*     */     
/* 110 */     iter = Service.providers(ParsedURLProtocolHandler.class);
/* 111 */     while (iter.hasNext()) {
/*     */       
/* 113 */       ParsedURLProtocolHandler handler = (ParsedURLProtocolHandler)iter.next();
/*     */ 
/*     */       
/* 116 */       registerHandler(handler);
/*     */     } 
/*     */ 
/*     */     
/* 120 */     return handlersMap;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static ParsedURLProtocolHandler getHandler(String protocol) {
/* 132 */     if (protocol == null) {
/* 133 */       return defaultHandler;
/*     */     }
/* 135 */     Map handlers = getHandlersMap();
/*     */     
/* 137 */     ParsedURLProtocolHandler ret = (ParsedURLProtocolHandler)handlers.get(protocol);
/* 138 */     if (ret == null)
/* 139 */       ret = defaultHandler; 
/* 140 */     return ret;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void registerHandler(ParsedURLProtocolHandler handler) {
/* 152 */     if (handler.getProtocolHandled() == null) {
/* 153 */       defaultHandler = handler;
/*     */       
/*     */       return;
/*     */     } 
/* 157 */     Map handlers = getHandlersMap();
/* 158 */     handlers.put(handler.getProtocolHandled(), handler);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 170 */   public static InputStream checkGZIP(InputStream is) throws IOException { return ParsedURLData.checkGZIP(is); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public ParsedURL(String urlStr) {
/* 178 */     this.userAgent = getGlobalUserAgent();
/* 179 */     this.data = parseURL(urlStr);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public ParsedURL(URL url) {
/* 192 */     this.userAgent = getGlobalUserAgent();
/* 193 */     this.data = new ParsedURLData(url);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public ParsedURL(String baseStr, String urlStr) {
/* 203 */     this.userAgent = getGlobalUserAgent();
/* 204 */     if (baseStr != null) {
/* 205 */       this.data = parseURL(baseStr, urlStr);
/*     */     } else {
/* 207 */       this.data = parseURL(urlStr);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public ParsedURL(URL baseURL, String urlStr) {
/* 217 */     this.userAgent = getGlobalUserAgent();
/*     */     
/* 219 */     if (baseURL != null) {
/* 220 */       this.data = parseURL(new ParsedURL(baseURL), urlStr);
/*     */     } else {
/* 222 */       this.data = parseURL(urlStr);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public ParsedURL(ParsedURL baseURL, String urlStr) {
/* 232 */     if (baseURL != null) {
/* 233 */       this.userAgent = baseURL.getUserAgent();
/* 234 */       this.data = parseURL(baseURL, urlStr);
/*     */     } else {
/* 236 */       this.data = parseURL(urlStr);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 245 */   public String toString() { return this.data.toString(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean equals(Object obj) {
/* 254 */     if (obj == null) return false; 
/* 255 */     if (!(obj instanceof ParsedURL))
/* 256 */       return false; 
/* 257 */     ParsedURL purl = (ParsedURL)obj;
/* 258 */     return this.data.equals(purl.data);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 267 */   public int hashCode() { return this.data.hashCode(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 276 */   public boolean complete() { return this.data.complete(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 284 */   public String getUserAgent() { return this.userAgent; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 291 */   public void setUserAgent(String userAgent) { this.userAgent = userAgent; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getProtocol() {
/* 299 */     if (this.data.protocol == null) return null; 
/* 300 */     return this.data.protocol;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getHost() {
/* 308 */     if (this.data.host == null) return null; 
/* 309 */     return this.data.host;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 316 */   public int getPort() { return this.data.port; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getPath() {
/* 325 */     if (this.data.path == null) return null; 
/* 326 */     return this.data.path;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getRef() {
/* 333 */     if (this.data.ref == null) return null; 
/* 334 */     return this.data.ref;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 343 */   public String getPortStr() { return this.data.getPortStr(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 351 */   public String getContentType() { return this.data.getContentType(this.userAgent); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 359 */   public String getContentTypeMediaType() { return this.data.getContentTypeMediaType(this.userAgent); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 367 */   public String getContentTypeCharset() { return this.data.getContentTypeCharset(this.userAgent); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 374 */   public boolean hasContentTypeParameter(String param) { return this.data.hasContentTypeParameter(this.userAgent, param); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 382 */   public String getContentEncoding() { return this.data.getContentEncoding(this.userAgent); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 390 */   public InputStream openStream() throws IOException { return this.data.openStream(this.userAgent, null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public InputStream openStream(String mimeType) throws IOException {
/* 401 */     List mt = new ArrayList(1);
/* 402 */     mt.add(mimeType);
/* 403 */     return this.data.openStream(this.userAgent, mt.iterator());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public InputStream openStream(String[] mimeTypes) throws IOException {
/* 414 */     List mt = new ArrayList(mimeTypes.length);
/* 415 */     for (int i = 0; i < mimeTypes.length; i++)
/* 416 */       mt.add(mimeTypes[i]); 
/* 417 */     return this.data.openStream(this.userAgent, mt.iterator());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 429 */   public InputStream openStream(Iterator mimeTypes) throws IOException { return this.data.openStream(this.userAgent, mimeTypes); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 437 */   public InputStream openStreamRaw() throws IOException { return this.data.openStreamRaw(this.userAgent, null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public InputStream openStreamRaw(String mimeType) throws IOException {
/* 448 */     List mt = new ArrayList(1);
/* 449 */     mt.add(mimeType);
/* 450 */     return this.data.openStreamRaw(this.userAgent, mt.iterator());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public InputStream openStreamRaw(String[] mimeTypes) throws IOException {
/* 461 */     List mt = new ArrayList(mimeTypes.length);
/* 462 */     for (int i = 0; i < mimeTypes.length; i++)
/* 463 */       mt.add(mimeTypes[i]); 
/* 464 */     return this.data.openStreamRaw(this.userAgent, mt.iterator());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 476 */   public InputStream openStreamRaw(Iterator mimeTypes) throws IOException { return this.data.openStreamRaw(this.userAgent, mimeTypes); }
/*     */ 
/*     */ 
/*     */   
/* 480 */   public boolean sameFile(ParsedURL other) { return this.data.sameFile(other.data); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static String getProtocol(String urlStr) {
/* 490 */     if (urlStr == null) return null; 
/* 491 */     int idx = 0, len = urlStr.length();
/*     */     
/* 493 */     if (len == 0) return null;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 499 */     char ch = urlStr.charAt(idx);
/*     */ 
/*     */ 
/*     */     
/* 503 */     while (ch == '-' || ch == '+' || ch == '.' || (ch >= 'a' && ch <= 'z') || (ch >= 'A' && ch <= 'Z')) {
/*     */       
/* 505 */       idx++;
/* 506 */       if (idx == len) {
/* 507 */         ch = Character.MIN_VALUE;
/*     */         break;
/*     */       } 
/* 510 */       ch = urlStr.charAt(idx);
/*     */     } 
/* 512 */     if (ch == ':')
/*     */     {
/* 514 */       return urlStr.substring(0, idx).toLowerCase();
/*     */     }
/* 516 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static ParsedURLData parseURL(String urlStr) {
/* 524 */     ParsedURLProtocolHandler handler = getHandler(getProtocol(urlStr));
/* 525 */     return handler.parseURL(urlStr);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static ParsedURLData parseURL(String baseStr, String urlStr) {
/* 535 */     if (baseStr == null) {
/* 536 */       return parseURL(urlStr);
/*     */     }
/* 538 */     ParsedURL purl = new ParsedURL(baseStr);
/* 539 */     return parseURL(purl, urlStr);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static ParsedURLData parseURL(ParsedURL baseURL, String urlStr) {
/* 549 */     if (baseURL == null) {
/* 550 */       return parseURL(urlStr);
/*     */     }
/* 552 */     String protocol = getProtocol(urlStr);
/* 553 */     if (protocol == null)
/* 554 */       protocol = baseURL.getProtocol(); 
/* 555 */     ParsedURLProtocolHandler handler = getHandler(protocol);
/* 556 */     return handler.parseURL(baseURL, urlStr);
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-util.jar!\org\apache\bati\\util\ParsedURL.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */