/*     */ package org.apache.batik.util;
/*     */ 
/*     */ import java.io.BufferedInputStream;
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.net.MalformedURLException;
/*     */ import java.net.URL;
/*     */ import java.net.URLConnection;
/*     */ import java.util.Iterator;
/*     */ import java.util.LinkedList;
/*     */ import java.util.List;
/*     */ import java.util.zip.GZIPInputStream;
/*     */ import java.util.zip.InflaterInputStream;
/*     */ import java.util.zip.ZipException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class ParsedURLData
/*     */ {
/*     */   protected static final String HTTP_USER_AGENT_HEADER = "User-Agent";
/*     */   protected static final String HTTP_ACCEPT_HEADER = "Accept";
/*     */   protected static final String HTTP_ACCEPT_LANGUAGE_HEADER = "Accept-Language";
/*     */   protected static final String HTTP_ACCEPT_ENCODING_HEADER = "Accept-Encoding";
/*  49 */   protected static List acceptedEncodings = new LinkedList(); public static final byte[] GZIP_MAGIC;
/*     */   static  {
/*  51 */     acceptedEncodings.add("gzip");
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  58 */     GZIP_MAGIC = new byte[] { 31, -117 };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static InputStream checkGZIP(InputStream is) throws IOException {
/*  70 */     if (!is.markSupported())
/*  71 */       is = new BufferedInputStream(is); 
/*  72 */     byte[] data = new byte[2];
/*     */     try {
/*  74 */       is.mark(2);
/*  75 */       is.read(data);
/*  76 */       is.reset();
/*     */     } catch (Exception ex) {
/*  78 */       is.reset();
/*  79 */       return is;
/*     */     } 
/*  81 */     if (data[0] == GZIP_MAGIC[0] && data[1] == GZIP_MAGIC[1])
/*     */     {
/*  83 */       return new GZIPInputStream(is);
/*     */     }
/*  85 */     if ((data[0] & 0xF) == 8 && data[0] >>> 4 <= 7) {
/*     */ 
/*     */       
/*  88 */       int chk = (data[0] & 0xFF) * 256 + (data[1] & 0xFF);
/*     */       
/*  90 */       if (chk % 31 == 0) {
/*     */         
/*     */         try {
/*     */ 
/*     */           
/*  95 */           is.mark(100);
/*  96 */           ret = new InflaterInputStream(is);
/*  97 */           if (!ret.markSupported())
/*  98 */             ret = new BufferedInputStream(ret); 
/*  99 */           ret.mark(2);
/* 100 */           ret.read(data);
/* 101 */           is.reset();
/* 102 */           return new InflaterInputStream(is);
/*     */         } catch (ZipException ze) {
/*     */           
/* 105 */           is.reset();
/* 106 */           return is;
/*     */         } 
/*     */       }
/*     */     } 
/*     */     
/* 111 */     return is;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 120 */   public String protocol = null;
/* 121 */   public String host = null;
/* 122 */   public int port = -1;
/* 123 */   public String path = null;
/* 124 */   public String ref = null;
/* 125 */   public String contentType = null;
/* 126 */   public String contentEncoding = null;
/*     */   
/* 128 */   public InputStream stream = null;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean hasBeenOpened = false;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected String contentTypeMediaType;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected String contentTypeCharset;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public ParsedURLData(URL url) {
/* 151 */     this.protocol = url.getProtocol();
/* 152 */     if (this.protocol != null && this.protocol.length() == 0) {
/* 153 */       this.protocol = null;
/*     */     }
/* 155 */     this.host = url.getHost();
/* 156 */     if (this.host != null && this.host.length() == 0) {
/* 157 */       this.host = null;
/*     */     }
/* 159 */     this.port = url.getPort();
/*     */     
/* 161 */     this.path = url.getFile();
/* 162 */     if (this.path != null && this.path.length() == 0) {
/* 163 */       this.path = null;
/*     */     }
/* 165 */     this.ref = url.getRef();
/* 166 */     if (this.ref != null && this.ref.length() == 0) {
/* 167 */       this.ref = null;
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected URL buildURL() throws MalformedURLException {
/* 182 */     if (this.protocol != null && this.host != null) {
/* 183 */       String file = "";
/* 184 */       if (this.path != null)
/* 185 */         file = this.path; 
/* 186 */       if (this.port == -1) {
/* 187 */         return new URL(this.protocol, this.host, file);
/*     */       }
/* 189 */       return new URL(this.protocol, this.host, this.port, file);
/*     */     } 
/*     */     
/* 192 */     return new URL(toString());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int hashCode() {
/* 199 */     int hc = this.port;
/* 200 */     if (this.protocol != null)
/* 201 */       hc ^= this.protocol.hashCode(); 
/* 202 */     if (this.host != null) {
/* 203 */       hc ^= this.host.hashCode();
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 208 */     if (this.path != null) {
/* 209 */       int len = this.path.length();
/* 210 */       if (len > 20) {
/* 211 */         hc ^= this.path.substring(len - 20).hashCode();
/*     */       } else {
/* 213 */         hc ^= this.path.hashCode();
/*     */       } 
/* 215 */     }  if (this.ref != null) {
/* 216 */       int len = this.ref.length();
/* 217 */       if (len > 20) {
/* 218 */         hc ^= this.ref.substring(len - 20).hashCode();
/*     */       } else {
/* 220 */         hc ^= this.ref.hashCode();
/*     */       } 
/*     */     } 
/* 223 */     return hc;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean equals(Object obj) {
/* 230 */     if (obj == null) return false; 
/* 231 */     if (!(obj instanceof ParsedURLData)) {
/* 232 */       return false;
/*     */     }
/* 234 */     ParsedURLData ud = (ParsedURLData)obj;
/* 235 */     if (ud.port != this.port) {
/* 236 */       return false;
/*     */     }
/* 238 */     if (ud.protocol == null)
/* 239 */     { if (this.protocol != null)
/* 240 */         return false;  }
/* 241 */     else { if (this.protocol == null)
/* 242 */         return false; 
/* 243 */       if (!ud.protocol.equals(this.protocol))
/* 244 */         return false;  }
/*     */     
/* 246 */     if (ud.host == null)
/* 247 */     { if (this.host != null)
/* 248 */         return false;  }
/* 249 */     else { if (this.host == null)
/* 250 */         return false; 
/* 251 */       if (!ud.host.equals(this.host))
/* 252 */         return false;  }
/*     */     
/* 254 */     if (ud.ref == null)
/* 255 */     { if (this.ref != null)
/* 256 */         return false;  }
/* 257 */     else { if (this.ref == null)
/* 258 */         return false; 
/* 259 */       if (!ud.ref.equals(this.ref))
/* 260 */         return false;  }
/*     */     
/* 262 */     if (ud.path == null)
/* 263 */     { if (this.path != null)
/* 264 */         return false;  }
/* 265 */     else { if (this.path == null)
/* 266 */         return false; 
/* 267 */       if (!ud.path.equals(this.path))
/* 268 */         return false;  }
/*     */     
/* 270 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getContentType(String userAgent) {
/* 278 */     if (this.contentType != null) {
/* 279 */       return this.contentType;
/*     */     }
/* 281 */     if (!this.hasBeenOpened) {
/*     */       try {
/* 283 */         openStreamInternal(userAgent, null, null);
/* 284 */       } catch (IOException ioe) {}
/*     */     }
/*     */     
/* 287 */     return this.contentType;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getContentTypeMediaType(String userAgent) {
/* 295 */     if (this.contentTypeMediaType != null) {
/* 296 */       return this.contentTypeMediaType;
/*     */     }
/*     */     
/* 299 */     extractContentTypeParts(userAgent);
/*     */     
/* 301 */     return this.contentTypeMediaType;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getContentTypeCharset(String userAgent) {
/* 309 */     if (this.contentTypeMediaType != null) {
/* 310 */       return this.contentTypeCharset;
/*     */     }
/*     */     
/* 313 */     extractContentTypeParts(userAgent);
/*     */     
/* 315 */     return this.contentTypeCharset;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean hasContentTypeParameter(String userAgent, String param) {
/* 322 */     getContentType(userAgent);
/* 323 */     if (this.contentType == null) {
/* 324 */       return false;
/*     */     }
/* 326 */     int i = 0;
/* 327 */     int len = this.contentType.length();
/* 328 */     int plen = param.length();
/* 329 */     while (i < len) {
/* 330 */       switch (this.contentType.charAt(i)) {
/*     */         case ' ':
/*     */         case ';':
/*     */           break;
/*     */       } 
/* 335 */       i++;
/*     */     } 
/* 337 */     if (i == len) {
/* 338 */       this.contentTypeMediaType = this.contentType;
/*     */     } else {
/* 340 */       this.contentTypeMediaType = this.contentType.substring(0, i);
/*     */     } 
/*     */     label41: while (true)
/* 343 */     { if (i >= len || this.contentType.charAt(i) == ';')
/*     */       
/*     */       { 
/* 346 */         if (i == len) {
/* 347 */           return false;
/*     */         }
/* 349 */         i++;
/* 350 */         while (i < len && this.contentType.charAt(i) == ' ') {
/* 351 */           i++;
/*     */         }
/* 353 */         if (i >= len - plen - 1) {
/* 354 */           return false;
/*     */         }
/* 356 */         for (int j = 0; j < plen; j++) {
/* 357 */           if (this.contentType.charAt(i++) != param.charAt(j)) {
/*     */             continue label41;
/*     */           }
/*     */         } 
/* 361 */         if (this.contentType.charAt(i) == '=')
/* 362 */           break;  continue; }  i++; }  return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void extractContentTypeParts(String userAgent) {
/* 372 */     getContentType(userAgent);
/* 373 */     if (this.contentType == null) {
/*     */       return;
/*     */     }
/* 376 */     int i = 0;
/* 377 */     int len = this.contentType.length();
/* 378 */     while (i < len) {
/* 379 */       switch (this.contentType.charAt(i)) {
/*     */         case ' ':
/*     */         case ';':
/*     */           break;
/*     */       } 
/* 384 */       i++;
/*     */     } 
/* 386 */     if (i == len) {
/* 387 */       this.contentTypeMediaType = this.contentType;
/*     */     } else {
/* 389 */       this.contentTypeMediaType = this.contentType.substring(0, i);
/*     */     } 
/*     */     while (true)
/* 392 */     { if (i >= len || this.contentType.charAt(i) == ';')
/*     */       
/*     */       { 
/* 395 */         if (i == len) {
/*     */           return;
/*     */         }
/* 398 */         i++;
/* 399 */         while (i < len && this.contentType.charAt(i) == ' ') {
/* 400 */           i++;
/*     */         }
/* 402 */         if (i >= len - 8) {
/*     */           return;
/*     */         }
/* 405 */         if (this.contentType.charAt(i++) != 'c' || 
/* 406 */           this.contentType.charAt(i++) != 'h' || 
/* 407 */           this.contentType.charAt(i++) != 'a' || 
/* 408 */           this.contentType.charAt(i++) != 'r' || 
/* 409 */           this.contentType.charAt(i++) != 's' || 
/* 410 */           this.contentType.charAt(i++) != 'e' || 
/* 411 */           this.contentType.charAt(i++) != 't' || 
/* 412 */           this.contentType.charAt(i++) != '=')
/* 413 */           continue;  break; }  i++; }  int j = i;
/* 414 */     while (i < len) {
/* 415 */       switch (this.contentType.charAt(i)) {
/*     */         case ' ':
/*     */         case ';':
/*     */           break;
/*     */       } 
/* 420 */       i++;
/*     */     } 
/* 422 */     this.contentTypeCharset = this.contentType.substring(j, i);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getContentEncoding(String userAgent) {
/* 433 */     if (this.contentEncoding != null) {
/* 434 */       return this.contentEncoding;
/*     */     }
/* 436 */     if (!this.hasBeenOpened) {
/*     */       try {
/* 438 */         openStreamInternal(userAgent, null, null);
/* 439 */       } catch (IOException ioe) {}
/*     */     }
/*     */     
/* 442 */     return this.contentEncoding;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean complete() {
/*     */     try {
/* 452 */       buildURL();
/*     */     } catch (MalformedURLException mue) {
/* 454 */       return false;
/*     */     } 
/* 456 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public InputStream openStream(String userAgent, Iterator mimeTypes) throws IOException {
/* 471 */     InputStream raw = openStreamInternal(userAgent, mimeTypes, acceptedEncodings.iterator());
/*     */     
/* 473 */     if (raw == null)
/* 474 */       return null; 
/* 475 */     this.stream = null;
/*     */     
/* 477 */     return checkGZIP(raw);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public InputStream openStreamRaw(String userAgent, Iterator mimeTypes) throws IOException {
/* 492 */     InputStream ret = openStreamInternal(userAgent, mimeTypes, null);
/* 493 */     this.stream = null;
/* 494 */     return ret;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected InputStream openStreamInternal(String userAgent, Iterator mimeTypes, Iterator encodingTypes) throws IOException {
/* 501 */     if (this.stream != null) {
/* 502 */       return this.stream;
/*     */     }
/* 504 */     this.hasBeenOpened = true;
/*     */     
/* 506 */     URL url = null;
/*     */     try {
/* 508 */       url = buildURL();
/*     */     } catch (MalformedURLException mue) {
/* 510 */       throw new IOException("Unable to make sense of URL for connection");
/*     */     } 
/*     */ 
/*     */     
/* 514 */     if (url == null) {
/* 515 */       return null;
/*     */     }
/* 517 */     URLConnection urlC = url.openConnection();
/* 518 */     if (urlC instanceof java.net.HttpURLConnection) {
/* 519 */       if (userAgent != null) {
/* 520 */         urlC.setRequestProperty("User-Agent", userAgent);
/*     */       }
/* 522 */       if (mimeTypes != null) {
/* 523 */         String acceptHeader = "";
/* 524 */         while (mimeTypes.hasNext()) {
/* 525 */           acceptHeader = acceptHeader + mimeTypes.next();
/* 526 */           if (mimeTypes.hasNext())
/* 527 */             acceptHeader = acceptHeader + ","; 
/*     */         } 
/* 529 */         urlC.setRequestProperty("Accept", acceptHeader);
/*     */       } 
/*     */       
/* 532 */       if (encodingTypes != null) {
/* 533 */         String encodingHeader = "";
/* 534 */         while (encodingTypes.hasNext()) {
/* 535 */           encodingHeader = encodingHeader + encodingTypes.next();
/* 536 */           if (encodingTypes.hasNext())
/* 537 */             encodingHeader = encodingHeader + ","; 
/*     */         } 
/* 539 */         urlC.setRequestProperty("Accept-Encoding", encodingHeader);
/*     */       } 
/*     */ 
/*     */       
/* 543 */       this.contentType = urlC.getContentType();
/* 544 */       this.contentEncoding = urlC.getContentEncoding();
/*     */     } 
/*     */     
/* 547 */     return this.stream = urlC.getInputStream();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getPortStr() {
/* 555 */     String portStr = "";
/* 556 */     if (this.protocol != null) {
/* 557 */       portStr = portStr + this.protocol + ":";
/*     */     }
/* 559 */     if (this.host != null || this.port != -1) {
/* 560 */       portStr = portStr + "//";
/* 561 */       if (this.host != null) portStr = portStr + this.host; 
/* 562 */       if (this.port != -1) portStr = portStr + ":" + this.port;
/*     */     
/*     */     } 
/* 565 */     return portStr;
/*     */   }
/*     */   
/*     */   protected boolean sameFile(ParsedURLData other) {
/* 569 */     if (this == other) return true;
/*     */ 
/*     */ 
/*     */     
/* 573 */     if (this.port == other.port && (this.path == other.path || (this.path != null && this.path.equals(other.path))) && (this.host == other.host || (this.host != null && this.host.equals(other.host))) && (this.protocol == other.protocol || (this.protocol != null && this.protocol.equals(other.protocol))))
/*     */     {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 580 */       return true;
/*     */     }
/* 582 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String toString() {
/* 590 */     String ret = getPortStr();
/* 591 */     if (this.path != null) {
/* 592 */       ret = ret + this.path;
/*     */     }
/* 594 */     if (this.ref != null) {
/* 595 */       ret = ret + "#" + this.ref;
/*     */     }
/* 597 */     return ret;
/*     */   }
/*     */   
/*     */   public ParsedURLData() {}
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-util.jar!\org\apache\bati\\util\ParsedURLData.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */