/*     */ package org.apache.batik.util;
/*     */ 
/*     */ import java.util.Iterator;
/*     */ import java.util.NoSuchElementException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class RunnableQueue
/*     */   implements Runnable
/*     */ {
/*     */   public static final class RunnableQueueState
/*     */   {
/*     */     private final String value;
/*     */     
/*  41 */     private RunnableQueueState(String value) { this.value = value; }
/*     */     
/*  43 */     public String getValue() { return this.value; }
/*     */ 
/*     */     
/*  46 */     public String toString() { return "[RunnableQueueState: " + this.value + ']'; }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  52 */   public static final RunnableQueueState RUNNING = new RunnableQueueState("Running", null);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  59 */   public static final RunnableQueueState SUSPENDING = new RunnableQueueState("Suspending", null);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  66 */   public static final RunnableQueueState SUSPENDED = new RunnableQueueState("Suspended", null);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  78 */   protected final Object stateLock = new Object();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected boolean wasResumed;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  90 */   private final DoublyLinkedList list = new DoublyLinkedList();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int preemptCount;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected RunHandler runHandler;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private IdleRunnable idleRunnable;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private long idleRunnableWaitTime;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static RunnableQueue createRunnableQueue() {
/* 124 */     result = new RunnableQueue();
/* 125 */     synchronized (result) {
/* 126 */       HaltingThread ht = new HaltingThread(result, "RunnableQueue-" + threadCount++);
/*     */       
/* 128 */       ht.setDaemon(true);
/* 129 */       ht.start();
/* 130 */       while (result.getThread() == null) {
/*     */         try {
/* 132 */           result.wait();
/* 133 */         } catch (InterruptedException ie) {}
/*     */       } 
/*     */     } 
/*     */     
/* 137 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void run() {
/* 146 */     synchronized (this) {
/* 147 */       this.runnableQueueThread = (HaltingThread)Thread.currentThread();
/*     */ 
/*     */       
/* 150 */       notify();
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/*     */     try {
/* 156 */       while (!HaltingThread.hasBeenHalted()) {
/* 157 */         Runnable runnable; Link l; boolean callSuspended = false;
/* 158 */         boolean callResumed = false;
/*     */         
/* 160 */         synchronized (this.stateLock) {
/* 161 */           if (this.state != RUNNING) {
/* 162 */             this.state = SUSPENDED;
/* 163 */             callSuspended = true;
/*     */           } 
/*     */         } 
/* 166 */         if (callSuspended) {
/* 167 */           executionSuspended();
/*     */         }
/* 169 */         synchronized (this.stateLock) {
/* 170 */           while (this.state != RUNNING) {
/* 171 */             this.state = SUSPENDED;
/*     */ 
/*     */ 
/*     */             
/* 175 */             this.stateLock.notifyAll();
/*     */ 
/*     */             
/*     */             try {
/* 179 */               this.stateLock.wait();
/* 180 */             } catch (InterruptedException ie) {}
/*     */           } 
/*     */           
/* 183 */           if (this.wasResumed) {
/* 184 */             this.wasResumed = false;
/* 185 */             callResumed = true;
/*     */           } 
/*     */         } 
/*     */         
/* 189 */         if (callResumed) {
/* 190 */           executionResumed();
/*     */         }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 199 */         synchronized (this.list) {
/* 200 */           if (this.state == SUSPENDING)
/*     */             continue; 
/* 202 */           l = (Link)this.list.pop();
/* 203 */           if (this.preemptCount != 0) this.preemptCount--; 
/* 204 */           if (l == null) {
/*     */ 
/*     */             
/* 207 */             if (this.idleRunnable != null && (this.idleRunnableWaitTime = this.idleRunnable.getWaitTime()) < System.currentTimeMillis()) {
/*     */ 
/*     */               
/* 210 */               runnable = this.idleRunnable;
/*     */             } else {
/*     */               
/*     */               try {
/* 214 */                 if (this.idleRunnable != null && this.idleRunnableWaitTime != Float.MAX_VALUE) {
/*     */                   
/* 216 */                   long t = this.idleRunnableWaitTime - System.currentTimeMillis();
/*     */                   
/* 218 */                   if (t > 0L) {
/* 219 */                     this.list.wait(t);
/*     */                   }
/*     */                 } else {
/* 222 */                   this.list.wait();
/*     */                 } 
/* 224 */               } catch (InterruptedException ie) {}
/*     */ 
/*     */               
/*     */               continue;
/*     */             } 
/*     */           } else {
/* 230 */             runnable = l.runnable;
/*     */           } 
/*     */         } 
/*     */         
/* 234 */         runnableStart(runnable);
/*     */         
/*     */         try {
/* 237 */           runnable.run();
/*     */         } catch (ThreadDeath td) {
/*     */           
/* 240 */           throw td;
/*     */         }
/*     */         catch (Throwable t) {
/*     */           
/* 244 */           t.printStackTrace();
/*     */         } 
/*     */ 
/*     */         
/* 248 */         if (l != null) {
/* 249 */           l.unlock();
/*     */         }
/* 251 */         runnableInvoked(runnable);
/*     */       } 
/*     */     } finally {
/* 254 */       synchronized (this) {
/* 255 */         this.runnableQueueThread = null;
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 266 */   public HaltingThread getThread() { return this.runnableQueueThread; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void invokeLater(Runnable r) {
/* 276 */     if (this.runnableQueueThread == null) {
/* 277 */       throw new IllegalStateException("RunnableQueue not started or has exited");
/*     */     }
/*     */     
/* 280 */     synchronized (this.list) {
/* 281 */       this.list.push(new Link(r));
/* 282 */       this.list.notify();
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void invokeAndWait(Runnable r) {
/* 295 */     if (this.runnableQueueThread == null) {
/* 296 */       throw new IllegalStateException("RunnableQueue not started or has exited");
/*     */     }
/*     */     
/* 299 */     if (this.runnableQueueThread == Thread.currentThread()) {
/* 300 */       throw new IllegalStateException("Cannot be called from the RunnableQueue thread");
/*     */     }
/*     */ 
/*     */     
/* 304 */     LockableLink l = new LockableLink(r);
/* 305 */     synchronized (this.list) {
/* 306 */       this.list.push(l);
/* 307 */       this.list.notify();
/*     */     } 
/* 309 */     l.lock();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void preemptLater(Runnable r) {
/* 322 */     if (this.runnableQueueThread == null) {
/* 323 */       throw new IllegalStateException("RunnableQueue not started or has exited");
/*     */     }
/*     */     
/* 326 */     synchronized (this.list) {
/* 327 */       this.list.add(this.preemptCount, new Link(r));
/* 328 */       this.preemptCount++;
/* 329 */       this.list.notify();
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void preemptAndWait(Runnable r) {
/* 344 */     if (this.runnableQueueThread == null) {
/* 345 */       throw new IllegalStateException("RunnableQueue not started or has exited");
/*     */     }
/*     */     
/* 348 */     if (this.runnableQueueThread == Thread.currentThread()) {
/* 349 */       throw new IllegalStateException("Cannot be called from the RunnableQueue thread");
/*     */     }
/*     */ 
/*     */     
/* 353 */     LockableLink l = new LockableLink(r);
/* 354 */     synchronized (this.list) {
/* 355 */       this.list.add(this.preemptCount, l);
/* 356 */       this.preemptCount++;
/* 357 */       this.list.notify();
/*     */     } 
/* 359 */     l.lock();
/*     */   }
/*     */   
/*     */   public RunnableQueueState getQueueState() {
/* 363 */     synchronized (this.stateLock) {
/* 364 */       return this.state;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void suspendExecution(boolean waitTillSuspended) {
/* 380 */     if (this.runnableQueueThread == null) {
/* 381 */       throw new IllegalStateException("RunnableQueue not started or has exited");
/*     */     }
/*     */ 
/*     */     
/* 385 */     synchronized (this.stateLock) {
/* 386 */       this.wasResumed = false;
/*     */       
/* 388 */       if (this.state == SUSPENDED) {
/*     */ 
/*     */         
/* 391 */         this.stateLock.notifyAll();
/*     */         
/*     */         return;
/*     */       } 
/* 395 */       if (this.state == RUNNING) {
/* 396 */         this.state = SUSPENDING;
/* 397 */         synchronized (this.list) {
/*     */ 
/*     */ 
/*     */           
/* 401 */           this.list.notify();
/*     */         } 
/*     */       } 
/*     */       
/* 405 */       if (waitTillSuspended) {
/* 406 */         while (this.state == SUSPENDING) {
/*     */           try {
/* 408 */             this.stateLock.wait();
/* 409 */           } catch (InterruptedException ie) {}
/*     */         } 
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void resumeExecution() {
/* 421 */     if (this.runnableQueueThread == null) {
/* 422 */       throw new IllegalStateException("RunnableQueue not started or has exited");
/*     */     }
/*     */ 
/*     */     
/* 426 */     synchronized (this.stateLock) {
/* 427 */       this.wasResumed = true;
/*     */       
/* 429 */       if (this.state != RUNNING) {
/* 430 */         this.state = RUNNING;
/* 431 */         this.stateLock.notifyAll();
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 441 */   public Object getIteratorLock() { return this.list; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Iterator iterator() {
/* 448 */     return new Iterator(this) { RunnableQueue.Link head; RunnableQueue.Link link;
/*     */         private final RunnableQueue this$0;
/*     */         
/*     */         public boolean hasNext() {
/* 452 */           if (this.head == null) {
/* 453 */             return false;
/*     */           }
/* 455 */           if (this.link == null) {
/* 456 */             return true;
/*     */           }
/* 458 */           return (this.link != this.head);
/*     */         }
/*     */         public Object next() {
/* 461 */           if (this.head == null || this.head == this.link) {
/* 462 */             throw new NoSuchElementException();
/*     */           }
/* 464 */           if (this.link == null) {
/* 465 */             this.link = (RunnableQueue.Link)this.head.getNext();
/* 466 */             return this.head.runnable;
/*     */           } 
/* 468 */           Object result = this.link.runnable;
/* 469 */           this.link = (RunnableQueue.Link)this.link.getNext();
/* 470 */           return result;
/*     */         }
/*     */         
/* 473 */         public void remove() { throw new UnsupportedOperationException(); } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 482 */   public void setRunHandler(RunHandler rh) { this.runHandler = rh; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 489 */   public RunHandler getRunHandler() { return this.runHandler; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setIdleRunnable(IdleRunnable r) {
/* 496 */     synchronized (this.list) {
/* 497 */       this.idleRunnable = r;
/* 498 */       this.idleRunnableWaitTime = 0L;
/* 499 */       this.list.notify();
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void executionSuspended() {
/* 509 */     if (this.runHandler != null) {
/* 510 */       this.runHandler.executionSuspended(this);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void executionResumed() {
/* 520 */     if (this.runHandler != null) {
/* 521 */       this.runHandler.executionResumed(this);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void runnableStart(Runnable rable) {
/* 531 */     if (this.runHandler != null) {
/* 532 */       this.runHandler.runnableStart(this, rable);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void runnableInvoked(Runnable rable) {
/* 542 */     if (this.runHandler != null) {
/* 543 */       this.runHandler.runnableInvoked(this, rable);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static class RunHandlerAdapter
/*     */     implements RunHandler
/*     */   {
/*     */     public void runnableStart(RunnableQueue rq, Runnable r) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void runnableInvoked(RunnableQueue rq, Runnable r) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void executionSuspended(RunnableQueue rq) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void executionResumed(RunnableQueue rq) {}
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class Link
/*     */     extends DoublyLinkedList.Node
/*     */   {
/*     */     private final Runnable runnable;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 634 */     public Link(Runnable r) { this.runnable = r; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void unlock() {}
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class LockableLink
/*     */     extends Link
/*     */   {
/* 658 */     public LockableLink(Runnable r) { super(r); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 665 */     public boolean isLocked() { return this.locked; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void lock() {
/* 672 */       this.locked = true;
/* 673 */       notify();
/* 674 */       wait();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void unlock() {
/* 681 */       while (!this.locked) {
/*     */         try {
/* 683 */           wait();
/* 684 */         } catch (InterruptedException ie) {}
/*     */       } 
/*     */ 
/*     */       
/* 688 */       this.locked = false;
/*     */       
/* 690 */       notify();
/*     */     }
/*     */   }
/*     */   
/*     */   public static interface RunHandler {
/*     */     void runnableStart(RunnableQueue param1RunnableQueue, Runnable param1Runnable);
/*     */     
/*     */     void runnableInvoked(RunnableQueue param1RunnableQueue, Runnable param1Runnable);
/*     */     
/*     */     void executionSuspended(RunnableQueue param1RunnableQueue);
/*     */     
/*     */     void executionResumed(RunnableQueue param1RunnableQueue);
/*     */   }
/*     */   
/*     */   public static interface IdleRunnable extends Runnable {
/*     */     long getWaitTime();
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-util.jar!\org\apache\bati\\util\RunnableQueue.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */